import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:provider/provider.dart';
import 'package:{{#snakeCase}}{{project_name}}{{/snakeCase}}/styles/themes.dart';

/// Заголовок страницы
///
/// [backTitle] - название предыдущей страницы для кнопки возврата
///
/// [customBackTitle] - компонент кнопки возврата
///
/// [backTitleRightWidget] - виджет, который отображается в правой части backTitle'а
///
/// [onBackTitleTap] - действие при нажатии на кнопку возврата
///
/// [onHeaderTap] - действие при тапе на хедер
///
/// [mainTitle] - название текущей страницы для заголовка
///
/// [customMainTitle] - компонент заголовка
///
/// [height] - высота хедера
class HeaderAppBar extends StatelessWidget implements PreferredSizeWidget {
  const HeaderAppBar({
    Key? key,
    this.backTitle,
    this.backTitleRightWidget,
    this.customBackTitle,
    this.onBackTitleTap,
    this.mainTitle,
    this.customMainTitle,
    this.height,
    this.onHeaderTap,
    this.backgroundColor,
    this.backTitleColor,
  }) : super(key: key);

  final String? backTitle;
  final Widget? backTitleRightWidget;
  final Widget? customBackTitle;
  final Color? backgroundColor;
  final Color? backTitleColor;
  final void Function()? onBackTitleTap;
  final double? height;
  final String? mainTitle;
  final Widget? customMainTitle;
  final void Function()? onHeaderTap;

  @override
  Widget build(BuildContext context) {
    AppTheme theme = context.read<AppTheme>();

    return AppBar(
      flexibleSpace: GestureDetector(
        onTap: onHeaderTap,
        child: SingleChildScrollView(
          physics: const NeverScrollableScrollPhysics(),
          child: Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              SizedBox(
                height: MediaQuery.of(context).padding.top + 15,
              ),
              Padding(
                padding: const EdgeInsets.only(left: 5),
                child: customBackTitle ??
                    Row(
                      mainAxisAlignment: MainAxisAlignment.spaceBetween,
                      children: [
                        GestureDetector(
                          behavior: HitTestBehavior.opaque,
                          onTap: onBackTitleTap ?? () => context.router.pop(),
                          child: Row(
                            mainAxisSize: MainAxisSize.min,
                            children: [
                              Icon(
                                Icons.arrow_back_ios_rounded,
                                color: backTitleColor ?? Colors.black,
                              ),
                              const SizedBox(width: 5),
                              Text(
                                backTitle ?? "",
                                style: theme.textStyles.title1.copyWith(
                                  color: backTitleColor ?? Colors.black,
                                ),
                              ),
                            ],
                          ),
                        ),
                        backTitleRightWidget ?? const SizedBox(),
                      ],
                    ),
              ),
              customMainTitle ??
                  SizedBox(
                    height: 70,
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.end,
                      children: [
                        Padding(
                          padding: const EdgeInsets.only(left: 25, bottom: 20),
                          child: Text(
                            mainTitle ?? "",
                            style: theme.textStyles.title1.copyWith(color: Colors.white),
                          ),
                        ),
                      ],
                    ),
                  ),
            ],
          ),
        ),
      ),
      shadowColor: Colors.transparent,
      backgroundColor: backgroundColor ?? Colors.grey,
    );
  }

  @override
  Size get preferredSize => Size.fromHeight(height ?? 120);
}
