import 'dart:io';

import 'package:mason/mason.dart';

mixin CLIMixin {
  /// Поддерживаемые типы: String, boolean, integer
  T getUserInput<T>({required String helpPhrase, required T defaultValue}) {
    stdout.write("$helpPhrase [$defaultValue]:  ");
    String output = stdin.readLineSync() ?? "";
    if (defaultValue is bool) {
      output = output.toLowerCase();
    }
    output = output.trim();
    if (defaultValue is bool) {
      return output.isNotEmpty
          ? (output == 'true' || output == 't') as T
          : defaultValue;
    }
    if (defaultValue is int) {
      return (int.tryParse(output) ?? defaultValue) as T;
    }
    if (defaultValue is String) {
      return output.isNotEmpty ? output as T : defaultValue;
    }
    throw UnsupportedError("Тип не поддерживается");
  }

  /// Генерация файлов через Mason bundle
  ///
  /// [path] - куда будет сгенерировано
  ///
  /// [bundle] - mason bundle
  ///
  /// [params] - параметры для Mason bundle'а
  Future<void> generateBundle({
    required String path,
    required MasonBundle bundle,
    Map<String, dynamic>? params,
  }) async {
    final generator = await MasonGenerator.fromBundle(bundle);
    final dir = Directory(path);
    await generator.generate(
      DirectoryGeneratorTarget(dir),
      vars: params ?? {},
    );
  }
}
