part of 'swagger_command.dart';

/// Генерирует Freezed-модель по шаблону
///
/// [filename] - имя файла (snake_case)
///
/// [filenameCamelCase] - имя файла (camel_case)
///
/// [nestedModelName] - название внутренней модели (camel_case)
///
/// [parameters] - блок с полями модели
///
/// [comment] - комментарий к модели
String freezedTemplate({
  required String filename,
  required String filenameCamelCase,
  required String nestedModelName,
  required String parameters,
  String? imports,
  String? comment,
}) {
  return '''import 'package:freezed_annotation/freezed_annotation.dart';${imports != null ? '\n$imports' : ''}

part '$filename.g.dart';
part '$filename.freezed.dart';
${comment != null ? '\n/// $comment' : ''}
@freezed
// ignore_for_file: invalid_annotation_target
class $filenameCamelCase with _\$$filenameCamelCase {
  const factory $filenameCamelCase(
$parameters
  ) = $nestedModelName;

  factory $filenameCamelCase.fromJson(Map<String, dynamic> json) => _\$${filenameCamelCase}FromJson(json);
}
''';
}

String generateParameter({
  required String description,
  String? modelType,
  APIType? type,
  required String name,
}) {
  return '''
    /// $description
    @JsonKey(name: "$name") ${modelType ?? apiTypeToString(type)}? $name,

''';
}

String generateImport(String snakeCaseName) {
  return "import '$snakeCaseName.dart';\n";
}

/// Получаем по перечислению с типами нужный тип в строке
String apiTypeToString(APIType? type) {
  switch (type) {
    case APIType.string:
      return "String";
    case APIType.boolean:
      return "bool";
    case APIType.integer:
      return "int";
    case APIType.number:
      return "int";
    default:
      return "undefined";
  }
}
